#
# spec file for package python-ntfy
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020 Matthias Bach <marix@marix.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-ntfy
Version:        2.7.0
Release:        11.1
Summary:        A utility for sending push notifications
License:        GPL-3.0-only
Group:          Development/Languages/Python
URL:            https://github.com/dschep/ntfy
Source:         ntfy-%{version}.tar.xz
# https://github.com/dschep/ntfy/issues/247
Patch0:         python-ntfy-no-mock.patch
Patch1:         emoji-2.0-compatibility.patch
Patch2:         drop-misleading-shebangs.patch
Patch3:         python-311-compat.patch
Patch4:         python-312-compat.patch
BuildRequires:  %{python_module appdirs}
# test requirements
BuildRequires:  %{python_module emoji >= 1.6.2}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module ruamel.yaml}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-appdirs
Requires:       python-requests
Requires:       python-ruamel.yaml
Requires(post): update-alternatives
Requires(postun): update-alternatives
Suggests:       python-dnspython3
Suggests:       python-emoji >= 1.6.2
Suggests:       python-instapush
Suggests:       python-psutil
Suggests:       python-rocketchat-API
Suggests:       python-slacker
Suggests:       python-sleekxmpp
Suggests:       python-telegram-send
BuildArch:      noarch
%python_subpackages

%description
ntfy brings notification to your shell. It can automatically provide
desktop notifications when long running commands finish or it can send
push notifications to your phone when a specific command finishes.

Quickstart
----------

    $ ntfy send test
    # send a notification when the command `sleep 10` finishes
    # this sends the message '"sleep 10" succeeded in 0:10 minutes'
    $ ntfy done sleep 10

%prep
%autosetup -p1 -n ntfy-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/ntfy
%python_expand %fdupes %{buildroot}%{$python_sitelib}/ntfy*

%check
%pytest --ignore 'tests/test_xmpp.py' -k 'not test_xmpp'

%post
%python_install_alternative ntfy

%postun
%python_uninstall_alternative ntfy

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/ntfy
%{python_sitelib}/ntfy
%{python_sitelib}/ntfy-%{version}*-info

%changelog
* Mon May 20 2024 Matthias Bach <marix@marix.org>
- Stop building for Python 3.6 as python-emoji no longer supports
  it.
* Wed Jan  3 2024 Matthias Bach <marix@marix.org>
- Add python-312-compat.patch to achieve compatibility with Python
  3.12.
* Sat Jan  7 2023 Matthias Bach <marix@marix.org>
- Add python-311-compat.patch to achieve compatibility with Python
  3.11.
* Mon Jul 18 2022 Matthias Bach <marix@marix.org> - 2.7.0
- Add emoji-2.0-compatibility.patch to allow upgrade of
  python-ntfy to version 2.0.
- Add drop-misleading-shebangs.patch.
* Tue May  3 2022 pgajdos@suse.com
- added patches
  fix https://github.com/dschep/ntfy/issues/247
  + python-ntfy-no-mock.patch
* Thu Feb 17 2022 Matthias Bach <marix@marix.org> - 2.7.0
- Switch test execution to pytest to allow for deselecting tests of
  optional functionality for which we lack the requiired
  dependencies.
- Drop build dependency to the sleekxmpp Python module which got
  dropped from Factory.
* Mon Jan 10 2022 Matthias Bach <marix@marix.org>
- Stop using %%pyunittest as this seems to cause build failures on
  Leap
* Tue May 25 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Thu Dec 24 2020 Matthias Bach <marix@marix.org> - 2.7.0
- Modernise spec file
* Tue Apr 21 2020 Matthias Bach <marix@marix.org>
- Drop deprecated usage of %%python3_only in favour of
  %%python_alternative.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Nov 25 2018 marix@marix.org
- Update to ntfy 2.7.0.
  * Support customizing or disabling the notification icon.
  * Support cusotmizing the notification timeout.
  * Have auto-ntfy ignore htop by default.
  * Make auto-ntfy send notifications in the background so that
    control returns to the shell faster.
* Sun Apr 15 2018 marix@marix.org
- Switch source service to run offline instead of on checkout.
  This is required to be compatible with Factory policies.
* Wed Apr  4 2018 marix@marix.org
- Update to Ntfy 2.6.0
  * This version adds support for third party backends.
* Sat Mar 31 2018 marix@marix.org
- Fix the copyright note in the spec file.
* Sat Mar 31 2018 marix@marix.org
- Initial package:
  * Only packaged for Python 3 as this primarily provides the
    executable ntfy.
  * Source is taken from Github as the source distribution on PyPI
    lacks the tests.
  * The package suggests a couple Python packages which are
    currently not packaged for openSUSE. Given the strict naming
    convention for packaged Python packages this should be safe,
    though and magically work once those packages are made
    available.
